@@ -509,6 +509,11 @@ bool MySQL_Protocol::generate_pkt_EOF(bool send, void **ptr, unsigned int *len,
 				break;
 		}
 	}
+	if (*myds && (*myds)->myconn) {
+		if ((*myds)->myconn->options.no_backslash_escapes) {
+			internal_status += SERVER_STATUS_NO_BACKSLASH_ESCAPES;
+		}
+	}
 	memcpy(_ptr+l, &warnings, sizeof(uint16_t)); l+=sizeof(uint16_t);
 	memcpy(_ptr+l, &internal_status, sizeof(uint16_t));
 	
@@ -618,6 +623,11 @@ bool MySQL_Protocol::generate_pkt_OK(bool send, void **ptr, unsigned int *len, u
 				break;
 		}
 	}
+	if (*myds && (*myds)->myconn) {
+		if ((*myds)->myconn->options.no_backslash_escapes) {
+			internal_status += SERVER_STATUS_NO_BACKSLASH_ESCAPES;
+		}
+	}
 	memcpy(_ptr+l, &internal_status, sizeof(uint16_t)); l+=sizeof(uint16_t);
 	memcpy(_ptr+l, &warnings, sizeof(uint16_t)); l+=sizeof(uint16_t);
 	if (msg && strlen(msg)) {
@@ -1536,7 +1546,7 @@ bool MySQL_Protocol::process_pkt_handshake_response(unsigned char *pkt, unsigned
 			auth_plugin_id = 2;
 		}
 	}
-__switch_auth_plugin:
+//__switch_auth_plugin:
 	if (auth_plugin_id == 0) {
 		if ((*myds)->switching_auth_stage == 0) {
 			(*myds)->switching_auth_stage = 1;
@@ -1632,7 +1642,11 @@ __do_auth:
 		if (
 			((*myds)->sess->session_type == PROXYSQL_SESSION_ADMIN)
 		|| 
-			((*myds)->sess->session_type == PROXYSQL_SESSION_STATS) 
+			((*myds)->sess->session_type == PROXYSQL_SESSION_STATS)
+#if defined(TEST_AURORA) || defined(TEST_GALERA)
+		|| 
+			((*myds)->sess->session_type == PROXYSQL_SESSION_SQLITE)
+#endif // TEST_AURORA  || TEST_GALERA
 		) {
 			if (strcmp((const char *)user,mysql_thread___monitor_username)==0) {
 				proxy_scramble(reply, (*myds)->myconn->scramble_buff, mysql_thread___monitor_password);
@@ -1713,7 +1727,7 @@ __do_auth:
 				}
 			} else {
 				if (auth_plugin_id == 1) {
-					if (session_type == PROXYSQL_SESSION_MYSQL || session_type == PROXYSQL_SESSION_SQLITE || PROXYSQL_SESSION_ADMIN || PROXYSQL_SESSION_STATS) {
+					if (session_type == PROXYSQL_SESSION_MYSQL || session_type == PROXYSQL_SESSION_SQLITE || session_type == PROXYSQL_SESSION_ADMIN || session_type == PROXYSQL_SESSION_STATS) {
 						ret=proxy_scramble_sha1((char *)pass,(*myds)->myconn->scramble_buff,password+1, reply);
 						if (ret) {
 							if (sha1_pass==NULL) {
@@ -1726,7 +1740,7 @@ __do_auth:
 						}
 					}
 				} else { // mysql_clear_password
-					if (session_type == PROXYSQL_SESSION_MYSQL || session_type == PROXYSQL_SESSION_SQLITE || PROXYSQL_SESSION_ADMIN || PROXYSQL_SESSION_STATS) {
+					if (session_type == PROXYSQL_SESSION_MYSQL || session_type == PROXYSQL_SESSION_SQLITE || session_type == PROXYSQL_SESSION_ADMIN || session_type == PROXYSQL_SESSION_STATS) {
 /*
 						char sha1_2[SHA_DIGEST_LENGTH+1];
 						sha1_2[SHA_DIGEST_LENGTH]='\0';
@@ -2269,7 +2283,7 @@ unsigned int MySQL_ResultSet::add_row2(MYSQL_ROWS *row, unsigned char *offset) {
 }
 
 void MySQL_ResultSet::add_eof() {
-	PtrSize_t pkt;
+	//PtrSize_t pkt;
 	if (myprot) {
 		unsigned int nTrx=myds->sess->NumActiveTransactions();
 		uint16_t setStatus = (nTrx ? SERVER_STATUS_IN_TRANS : 0 );
