@@ -35,6 +35,7 @@ static char * session_vars[]= {
 	(char *)"UNIQUE_CHECKS",
 	(char *)"AUTO_INCREMENT_INCREMENT",
 	(char *)"AUTO_INCREMENT_OFFSET",
+	(char *)"TIMESTAMP",
 	(char *)"GROUP_CONCAT_MAX_LEN"
 };
 
@@ -202,6 +203,7 @@ MySQL_Connection::MySQL_Connection() {
 	options.server_version=NULL;
 	options.last_set_autocommit=-1;	// -1 = never set
 	options.autocommit=true;
+	options.no_backslash_escapes=false;
 	options.init_connect=NULL;
 	options.init_connect_sent=false;
 	options.ldap_user_variable=NULL;
@@ -229,6 +231,12 @@ MySQL_Connection::MySQL_Connection() {
 	processing_multi_statement=false;
 	proxy_debug(PROXY_DEBUG_MYSQL_CONNPOOL, 4, "Creating new MySQL_Connection %p\n", this);
 	local_stmts=new MySQL_STMTs_local_v14(false); // false by default, it is a backend
+	bytes_info.bytes_recv = 0;
+	bytes_info.bytes_sent = 0;
+	statuses.questions = 0;
+	statuses.myconnpoll_get = 0;
+	statuses.myconnpoll_put = 0;
+
 };
 
 MySQL_Connection::~MySQL_Connection() {
@@ -279,6 +287,12 @@ bool MySQL_Connection::set_autocommit(bool _ac) {
 	return _ac;
 }
 
+bool MySQL_Connection::set_no_backslash_escapes(bool _ac) {
+	proxy_debug(PROXY_DEBUG_MYSQL_CONNPOOL, 4, "Setting no_backslash_escapes %d\n", _ac);
+	options.no_backslash_escapes=_ac;
+	return _ac;
+}
+
 uint8_t MySQL_Connection::set_charset(uint8_t _c) {
 	proxy_debug(PROXY_DEBUG_MYSQL_CONNPOOL, 4, "Setting charset %d\n", _c);
 	options.charset=_c;
@@ -339,6 +353,14 @@ void MySQL_Connection::set_status_temporary_table(bool v) {
 	}
 }
 
+void MySQL_Connection::set_status_no_backslash_escapes(bool v) {
+	if (v) {
+		status_flags |= STATUS_MYSQL_CONNECTION_NO_BACKSLASH_ESCAPES;
+	} else {
+		status_flags &= ~STATUS_MYSQL_CONNECTION_NO_BACKSLASH_ESCAPES;
+	}
+}
+
 void MySQL_Connection::set_status_user_variable(bool v) {
 	if (v) {
 		status_flags |= STATUS_MYSQL_CONNECTION_USER_VARIABLE;
@@ -402,6 +424,10 @@ bool MySQL_Connection::get_status_temporary_table() {
 	return status_flags & STATUS_MYSQL_CONNECTION_TEMPORARY_TABLE;
 }
 
+bool MySQL_Connection::get_status_no_backslash_escapes() {
+	return status_flags & STATUS_MYSQL_CONNECTION_NO_BACKSLASH_ESCAPES;
+}
+
 bool MySQL_Connection::get_status_prepared_statement() {
 	return status_flags & STATUS_MYSQL_CONNECTION_PREPARED_STATEMENT;
 }
@@ -772,7 +798,10 @@ handler_again:
 			real_query_start();
 			__sync_fetch_and_add(&parent->queries_sent,1);
 			__sync_fetch_and_add(&parent->bytes_sent,query.length);
+			statuses.questions++;
 			myds->sess->thread->status_variables.queries_backends_bytes_sent+=query.length;
+			myds->bytes_info.bytes_sent += query.length;
+			bytes_info.bytes_sent += query.length;
 			if (myds->sess->with_gtid == true) {
 				__sync_fetch_and_add(&parent->queries_gtid_sync,1);
 			}
@@ -804,6 +833,8 @@ handler_again:
 			__sync_fetch_and_add(&parent->queries_sent,1);
 			__sync_fetch_and_add(&parent->bytes_sent,query.length);
 			myds->sess->thread->status_variables.queries_backends_bytes_sent+=query.length;
+			myds->bytes_info.bytes_sent += query.length;
+			bytes_info.bytes_sent += query.length;
 			if (async_exit_status) {
 				next_event(ASYNC_STMT_PREPARE_CONT);
 			} else {
@@ -836,6 +867,8 @@ handler_again:
 			__sync_fetch_and_add(&parent->queries_sent,1);
 			__sync_fetch_and_add(&parent->bytes_sent,query.stmt_meta->size);
 			myds->sess->thread->status_variables.queries_backends_bytes_sent+=query.stmt_meta->size;
+			myds->bytes_info.bytes_sent += query.stmt_meta->size;
+			bytes_info.bytes_sent += query.stmt_meta->size;
 			if (async_exit_status) {
 				next_event(ASYNC_STMT_EXECUTE_CONT);
 			} else {
@@ -898,6 +931,8 @@ handler_again:
 					}
 					__sync_fetch_and_add(&parent->bytes_recv,total_size);
 					myds->sess->thread->status_variables.queries_backends_bytes_recv+=total_size;
+					myds->bytes_info.bytes_recv += total_size;
+					bytes_info.bytes_recv += total_size;
 				}
 			}
 /*
@@ -1020,6 +1055,8 @@ handler_again:
 					unsigned int br=MyRS->add_row(mysql_row);
 					__sync_fetch_and_add(&parent->bytes_recv,br);
 					myds->sess->thread->status_variables.queries_backends_bytes_recv+=br;
+					myds->bytes_info.bytes_recv += br;
+					bytes_info.bytes_recv += br;
 					processed_bytes+=br;	// issue #527 : this variable will store the amount of bytes processed during this event
 					if (
 						(processed_bytes > (unsigned int)mysql_thread___threshold_resultset_size*8)
@@ -1631,13 +1668,95 @@ bool MySQL_Connection::MultiplexDisabled() {
 // status_flags stores information about the status of the connection
 // can be used to determine if multiplexing can be enabled or not
 	bool ret=false;
-	if (status_flags & (STATUS_MYSQL_CONNECTION_TRANSACTION|STATUS_MYSQL_CONNECTION_USER_VARIABLE|STATUS_MYSQL_CONNECTION_PREPARED_STATEMENT|STATUS_MYSQL_CONNECTION_LOCK_TABLES|STATUS_MYSQL_CONNECTION_TEMPORARY_TABLE|STATUS_MYSQL_CONNECTION_GET_LOCK|STATUS_MYSQL_CONNECTION_NO_MULTIPLEX|STATUS_MYSQL_CONNECTION_SQL_LOG_BIN0|STATUS_MYSQL_CONNECTION_FOUND_ROWS) ) {
+	if (status_flags & (STATUS_MYSQL_CONNECTION_TRANSACTION|STATUS_MYSQL_CONNECTION_USER_VARIABLE|STATUS_MYSQL_CONNECTION_PREPARED_STATEMENT|STATUS_MYSQL_CONNECTION_LOCK_TABLES|STATUS_MYSQL_CONNECTION_TEMPORARY_TABLE|STATUS_MYSQL_CONNECTION_GET_LOCK|STATUS_MYSQL_CONNECTION_NO_MULTIPLEX|STATUS_MYSQL_CONNECTION_SQL_LOG_BIN0|STATUS_MYSQL_CONNECTION_FOUND_ROWS|STATUS_MYSQL_CONNECTION_NO_BACKSLASH_ESCAPES) ) {
 		ret=true;
 	}
 	if (auto_increment_delay_token) return true;
 	return ret;
 }
 
+bool MySQL_Connection::IsKeepMultiplexEnabledVariables(char *query_digest_text) {
+	if (query_digest_text==NULL) return true;
+
+	char *query_digest_text_filter_select = NULL;
+	unsigned long query_digest_text_len=strlen(query_digest_text);
+	if (strncasecmp(query_digest_text,"SELECT ",strlen("SELECT "))==0){
+		query_digest_text_filter_select=(char*)malloc(query_digest_text_len-7+1);
+		memcpy(query_digest_text_filter_select,&query_digest_text[7],query_digest_text_len-7);
+		query_digest_text_filter_select[query_digest_text_len-7]='\0';
+	} else {
+		return false;
+	}
+	//filter @@session. and @@
+	char *match=NULL;
+	while (query_digest_text_filter_select && (match = strcasestr(query_digest_text_filter_select,"@@session."))) {
+		*match = '\0';
+		strcat(query_digest_text_filter_select, match+strlen("@@session."));
+	}
+	while (query_digest_text_filter_select && (match = strcasestr(query_digest_text_filter_select,"@@"))) {
+		*match = '\0';
+		strcat(query_digest_text_filter_select, match+strlen("@@"));
+	}
+
+	std::vector<char*>query_digest_text_filter_select_v;
+	char* query_digest_text_filter_select_tok = NULL;
+	if (query_digest_text_filter_select) {
+	query_digest_text_filter_select_tok = strtok(query_digest_text_filter_select, ",");
+	}
+	while(query_digest_text_filter_select_tok){
+		//filter "as"/space/alias,such as select @@version as a, @@version b
+		while (1){
+			char c = *query_digest_text_filter_select_tok;
+			if (!isspace(c)){
+				break;
+			}
+			query_digest_text_filter_select_tok++;
+		}
+		char* match_as;
+		match_as=strcasestr(query_digest_text_filter_select_tok," ");
+		if(match_as){
+			query_digest_text_filter_select_tok[match_as-query_digest_text_filter_select_tok]='\0';
+			query_digest_text_filter_select_v.push_back(query_digest_text_filter_select_tok);
+		}else{
+			query_digest_text_filter_select_v.push_back(query_digest_text_filter_select_tok);
+		}
+		query_digest_text_filter_select_tok=strtok(NULL, ",");
+	}
+
+	std::vector<char*>keep_multiplexing_variables_v;
+	char* keep_multiplexing_variables_tmp;
+	unsigned long keep_multiplexing_variables_len=strlen(mysql_thread___keep_multiplexing_variables);
+	keep_multiplexing_variables_tmp=(char*)malloc(keep_multiplexing_variables_len+1);
+	memcpy(keep_multiplexing_variables_tmp, mysql_thread___keep_multiplexing_variables, keep_multiplexing_variables_len);
+	keep_multiplexing_variables_tmp[keep_multiplexing_variables_len]='\0';
+	char* keep_multiplexing_variables_tok=strtok(keep_multiplexing_variables_tmp, " ,");
+	while (keep_multiplexing_variables_tok){
+		keep_multiplexing_variables_v.push_back(keep_multiplexing_variables_tok);
+		keep_multiplexing_variables_tok=strtok(NULL, " ,");
+	}
+
+	for (std::vector<char*>::iterator it=query_digest_text_filter_select_v.begin();it!=query_digest_text_filter_select_v.end();it++){
+		bool is_match=false;
+		for (std::vector<char*>::iterator it1=keep_multiplexing_variables_v.begin();it1!=keep_multiplexing_variables_v.end();it1++){
+			//printf("%s,%s\n",*it,*it1);
+			if (strncasecmp(*it,*it1,strlen(*it1))==0){
+				is_match=true;
+				break;
+			}
+		}
+		if(is_match){
+			is_match=false;
+			continue;
+		}else{
+			free(query_digest_text_filter_select);
+			free(keep_multiplexing_variables_tmp);
+			return false;
+		}
+	}
+	free(query_digest_text_filter_select);
+	free(keep_multiplexing_variables_tmp);
+	return true;
+}
 
 void MySQL_Connection::ProcessQueryAndSetStatusFlags(char *query_digest_text) {
 	if (query_digest_text==NULL) return;
@@ -1659,11 +1778,11 @@ void MySQL_Connection::ProcessQueryAndSetStatusFlags(char *query_digest_text) {
 	}
 	if (get_status_user_variable()==false) { // we search for variables only if not already set
 		if (mul!=2 && index(query_digest_text,'@')) { // mul = 2 has a special meaning : do not disable multiplex for variables in THIS QUERY ONLY
-			if (
-				strncasecmp(query_digest_text,"SELECT @@tx_isolation", strlen("SELECT @@tx_isolation"))
-				&&
-				strncasecmp(query_digest_text,"SELECT @@version", strlen("SELECT @@version"))
-			) {
+//			if (
+//				strncasecmp(query_digest_text,"SELECT @@tx_isolation", strlen("SELECT @@tx_isolation"))
+//				&&
+//				strncasecmp(query_digest_text,"SELECT @@version", strlen("SELECT @@version"))
+			if (!IsKeepMultiplexEnabledVariables(query_digest_text)) {
 				set_status_user_variable(true);
 			}
 		}
@@ -1828,6 +1947,7 @@ void MySQL_Connection::reset() {
 		options.init_connect = NULL;
 		options.init_connect_sent = false;
 	}
+	auto_increment_delay_token = 0;
 	if (options.ldap_user_variable) {
 		if (options.ldap_user_variable_value) {
 			free(options.ldap_user_variable_value);
