@@ -35,7 +35,8 @@ std::map<std::string,std::vector<string>> SetParser::parse() {
 #define VAR "(\\w+)"
 #define SPACES " *"
 //#define VAR_VALUE "((?:[\\w/\\d:\\+\\-]|,)+)"
-#define VAR_VALUE "((?:CONCAT\\((?:REPLACE\\()+@@sql_mode,(?:(?:'|\\w|,| |\"|\\))+(?:\\)))|(?:[\\w/\\d:\\+\\-]|,)+|(?:)))"
+//#define VAR_VALUE "((?:CONCAT\\((?:(REPLACE|CONCAT)\\()+@@sql_mode,(?:(?:'|\\w|,| |\"|\\))+(?:\\)))|(?:[@\\w/\\d:\\+\\-]|,)+|(?:)))"
+#define VAR_VALUE "(((?:CONCAT\\()*(?:((?: )*REPLACE|CONCAT)\\()+(?: )*@@sql_mode,(?:(?:'|\\w|,| |\"|\\))+(?:\\))*)|(?:[@\\w/\\d:\\+\\-]|,)+|(?:)))"
 
   const string pattern="(?:" NAMES SPACES QUOTES NAME_VALUE QUOTES "(?: +COLLATE +" QUOTES NAME_VALUE QUOTES "|)" "|" SESSION VAR SPACES "(?:|:)=" SPACES QUOTES VAR_VALUE QUOTES ") *,? *";
   re2::RE2 re(pattern, *opt2);
@@ -57,6 +58,7 @@ std::map<std::string,std::vector<string>> SetParser::parse() {
       }
     } else if (value4 != "") {
       // VARIABLE
+		value5.erase(value5.find_last_not_of(" \n\r\t\,")+1);
       key = value4;
       op.push_back(value5);
     }
